@@ -1,6 +1,7 @@
 from io import StringIO
 import logging
 import os
+from typing import Optional
 
 from pyiddidf import exceptions
 from pyiddidf.idd_objects import IDDField, IDDObject, IDDStructure, IDDGroup
@@ -21,7 +22,7 @@ class CurrentReadType:
     ReadingObjectMetaDataContents = 6
     ReadingFieldANValue = 7
     ReadingFieldMetaData = 8
-    ReadingFieldMetaDataOrNextANValue = 9
+    ReadingFieldMetaDataOrNextANValueOrNextObject = 9
     LookingForFieldMetaDataOrNextObject = 10
     LookingForFieldMetaDataOrNextField = 11
 
@@ -43,7 +44,7 @@ class IDDProcessor:
     """
 
     def __init__(self):
-        self.idd = None
+        self.idd: Optional[IDDStructure] = None
         self.idd_file_stream = None
         self.file_path = None
         self.group_flag_string = "\\group"
@@ -177,7 +178,11 @@ class IDDProcessor:
 
             # if we are on Windows, we may end up with "\r", so move the read and peeked characters forward once
             if peeked_char == "\r":  # pragma no cover -- we don't unit test on Windows, so this won't be caught
-                just_read_char = self.read_one_char()
+                # in this case, we currently have like peeked_char='\r' and just_read_char='A'
+                # we need to keep the just_read_char as it is, but move peeked char forward
+                currently_just_read_char = just_read_char
+                self.read_one_char()  # go ahead and digest the \r
+                just_read_char = currently_just_read_char
                 peeked_char = self.peek_one_char()
                 if not peeked_char:
                     peeked_char = "\n"
@@ -223,7 +228,7 @@ class IDDProcessor:
                     # first update the previous group
                     if cur_group is not None:
                         self.idd.groups.append(cur_group)
-                    group_declaration = token_builder
+                    group_declaration = token_builder.strip()
                     group_flag_index = group_declaration.find(self.group_flag_string)
                     if group_flag_index == -1:  # pragma: no cover
                         # add error to error report
@@ -245,7 +250,7 @@ class IDDProcessor:
                 # for now I will assume that the single line objects can't have metadata
                 # so read until either a comma or semicolon, also trap for errors if we reach the end of line or comment
                 if peeked_char == ",":
-                    object_title = token_builder
+                    object_title = token_builder.strip()
                     cur_object = IDDObject(object_title)
                     token_builder = ""
                     self.read_one_char()  # to clear the comma
@@ -345,14 +350,14 @@ class IDDProcessor:
                         last_field_for_object = False
                     elif peeked_char == ";":
                         last_field_for_object = True
-                    read_status = CurrentReadType.ReadingFieldMetaDataOrNextANValue
+                    read_status = CurrentReadType.ReadingFieldMetaDataOrNextANValueOrNextObject
                 elif peeked_char == "\n":  # pragma: no cover
                     raise exceptions.ProcessingException(
                         "Blank or erroneous ""AN"" field index value",
                         line_index=line_index,
                         object_name=cur_object.name)
 
-            elif read_status == CurrentReadType.ReadingFieldMetaDataOrNextANValue:
+            elif read_status == CurrentReadType.ReadingFieldMetaDataOrNextANValueOrNextObject:
 
                 if peeked_char == "\\":
                     token_builder = ""
@@ -364,12 +369,14 @@ class IDDProcessor:
                         cur_field.field_name = ""
                     cur_object.fields.append(cur_field)
                     read_status = CurrentReadType.ReadingFieldANValue
-                elif just_read_char == ';' and peeked_char == '\n':
+                # If we hit a newline while searching here, we are moving onto the next object
+                elif peeked_char == '\n':
                     token_builder = ""
                     # this is hit when we end an object when an "AN" declaration and nothing after it
                     if cur_field.field_name is None:
                         cur_field.field_name = ""
                     cur_object.fields.append(cur_field)
+                    cur_group.objects.append(cur_object)
                     read_status = CurrentReadType.ReadAnything
 
             elif read_status == CurrentReadType.ReadingFieldMetaData:
